pub enum Object {
Null,
Boolean(bool),
Integer(i64),
Real(f64),
String(Vec<u8>),
Name(String),
Array(Vec<Object>),
Dict(Vec<(String, Object)>),
Ref(u64),
Stream {
dict: Vec<(String, Object)>,
data: Vec<u8>,
},
}Expand description
PDF object types as specified in PDF 1.7 specification.
Variants
Null
Null object.
Boolean(bool)
Boolean object.
Integer(i64)
Integer object.
Real(f64)
Real (floating-point) object.
String(Vec<u8>)
String object (binary data, typically 8-bit or Unicode).
Name(String)
Name object.
Array(Vec<Object>)
Array object, containing other PDF objects.
Dict(Vec<(String, Object)>)
Dictionary object, key-value pairs.
Ref(u64)
Indirect reference object reference by object number.
Stream
Stream object, dictionary + data.
Implementations
Sourceimpl Object
impl Object
Sourcepub fn dict(
entries: impl IntoIterator<Item = (impl Into<String>, impl Into<Object>)>,
) -> Self
pub fn dict( entries: impl IntoIterator<Item = (impl Into<String>, impl Into<Object>)>, ) -> Self
Creates a new Dictionary object from key-value pairs.
Sourcepub fn array(items: impl IntoIterator<Item = impl Into<Object>>) -> Self
pub fn array(items: impl IntoIterator<Item = impl Into<Object>>) -> Self
Creates a new Array object.
Sourcepub fn string_utf16(s: &str) -> Self
pub fn string_utf16(s: &str) -> Self
Creates a new UTF-16BE encoded String object.
Sourcepub fn insert(
&mut self,
key: impl Into<String>,
value: impl Into<Object>,
) -> Result<()>
pub fn insert( &mut self, key: impl Into<String>, value: impl Into<Object>, ) -> Result<()>
Inserts a key-value pair into a dictionary object.
Returns an error if self is not a Dict.
Sourcepub fn get(&self, key: &str) -> Option<&Object>
pub fn get(&self, key: &str) -> Option<&Object>
Gets a value from a dictionary object by key. Returns None if the object is not a Dict or key doesn’t exist.