pub struct PageSize {
pub width: f64,
pub height: f64,
}Expand description
Page size in points (1 point = 1/72 inch).
Fields
width: f64height: f64Implementations
Sourceimpl PageSize
impl PageSize
Sourcepub const fn new(width: f64, height: f64) -> Self
pub const fn new(width: f64, height: f64) -> Self
Creates a new page size with given width and height.
Sourcepub fn landscape(&self) -> Self
pub fn landscape(&self) -> Self
Returns a landscape version of the page size (swaps width and height).
Sourcepub fn from_inches(width_in: f64, height_in: f64) -> Result<Self>
pub fn from_inches(width_in: f64, height_in: f64) -> Result<Self>
Converts inches to points.